API Reference
=============
All functionality is encapsulated in the WordCloud class.

.. toctree::
   :maxdepth: 2

.. automodule:: wordcloud
   :no-members:
   :no-inherited-members:

.. currentmodule:: wordcloud

.. autosummary::
   :toctree: generated/
   :template: class.rst

    WordCloud
    ImageColorGenerator

   :template: function.rst
   
   random_color_func
   colormap_color_func
   get_single_color_func
